@@ -16,14 +16,14 @@
     <message>
         <location filename="mainwindow.cpp" line="40"/>
         <location filename="mainwindow.cpp" line="126"/>
-        <location filename="mainwindow.cpp" line="270"/>
+        <location filename="mainwindow.cpp" line="285"/>
         <source>Enable GPS</source>
         <oldsource>Toggle GPS</oldsource>
         <translation>GPS einschalten</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="45"/>
-        <location filename="mainwindow.cpp" line="326"/>
+        <location filename="mainwindow.cpp" line="341"/>
         <source>Donate</source>
         <translation>Spenden</translation>
     </message>
@@ -40,9 +40,9 @@
     <message>
         <location filename="mainwindow.cpp" line="61"/>
         <location filename="mainwindow.cpp" line="62"/>
-        <location filename="mainwindow.cpp" line="231"/>
-        <location filename="mainwindow.cpp" line="232"/>
-        <location filename="mainwindow.cpp" line="702"/>
+        <location filename="mainwindow.cpp" line="246"/>
+        <location filename="mainwindow.cpp" line="247"/>
+        <location filename="mainwindow.cpp" line="717"/>
         <source>please select</source>
         <translation>bitte wählen</translation>
     </message>
@@ -61,13 +61,13 @@
         <translation type="obsolete">- bahn.de: absturz problem behoben&lt;br&gt;- kalender auswahl verbessert&lt;br&gt;- abfahrt/ankuft knopf verbessert</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="299"/>
+        <location filename="mainwindow.cpp" line="314"/>
         <source>Arrival time</source>
         <translation>Ankunft</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="89"/>
-        <location filename="mainwindow.cpp" line="295"/>
+        <location filename="mainwindow.cpp" line="310"/>
         <source>Departure time</source>
         <translation>Abfahrt</translation>
     </message>
@@ -88,7 +88,7 @@
     </message>
     <message>
         <location filename="mainwindow.cpp" line="122"/>
-        <location filename="mainwindow.cpp" line="276"/>
+        <location filename="mainwindow.cpp" line="291"/>
         <source>Disable GPS</source>
         <translation>GPS ausschalten</translation>
     </message>
@@ -106,22 +106,22 @@
         <translation type="obsolete">-bahn.de: fehler mit gps suche behoben&lt;br&gt;- Geburtstags Kalender wird nun nicht mehr als wählbarer kalender angezeigt.</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="237"/>
+        <location filename="mainwindow.cpp" line="252"/>
         <source>not supported</source>
         <translation>nicht unterstützt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="259"/>
+        <location filename="mainwindow.cpp" line="274"/>
         <source>&lt;br&gt;GPS is now available!&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist nun verfügbar!&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="271"/>
+        <location filename="mainwindow.cpp" line="286"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;disabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;aus&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="277"/>
+        <location filename="mainwindow.cpp" line="292"/>
         <source>&lt;br&gt;GPS is now &lt;b&gt;enabled&lt;/b&gt;&lt;br&gt;</source>
         <translation>&lt;br&gt;GPS ist jetzt &lt;b&gt;an&lt;/b&gt;&lt;br&gt;</translation>
     </message>
@@ -130,7 +130,7 @@
         <translation type="obsolete">Verbindung: </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="468"/>
+        <location filename="mainwindow.cpp" line="483"/>
         <source> to </source>
         <translation> nach </translation>
     </message>
@@ -168,12 +168,12 @@
         <translation type="obsolete">- sbb.ch: fehler im parser behoben</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="327"/>
+        <location filename="mainwindow.cpp" line="342"/>
         <source>Thank you for Donating!</source>
         <translation>Danke fürs spenden!</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="333"/>
+        <location filename="mainwindow.cpp" line="348"/>
         <source>by smurfy (maemo@smurfy.de)&lt;br&gt;Version </source>
         <translation>von smurfy (maemo@smurfy.de)&lt;br&gt;Version </translation>
     </message>
@@ -186,89 +186,92 @@
         <translation type="obsolete">- 131500.com.au backend hinzugefügt</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="154"/>
         <source>- bugfixes for 131500.com.au backend
 - support for portrait mode</source>
-        <translation>- fehlerbehebungen für  131500.com.au backend
+        <translation type="obsolete">- fehlerbehebungen für  131500.com.au backend
 - unterstützung für portrait modus</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="333"/>
         <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
-        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
+        <translation type="obsolete">&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;bahn.de&lt;/b&gt;, &lt;b&gt;mvv-muenchen.de&lt;/b&gt;, &lt;b&gt;sbb.ch&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="335"/>
+        <location filename="mainwindow.cpp" line="348"/>
+        <source>&lt;br&gt;&lt;br&gt;Current supported databackends:&lt;br&gt;&lt;b&gt;DB&lt;/b&gt;, &lt;b&gt;MVV&lt;/b&gt;, &lt;b&gt;SBB&lt;/b&gt;, &lt;b&gt;ÖBB&lt;/b&gt;, &lt;b&gt;Rejseplanen.dk&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;This or prior versions uses code contribution by:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</source>
+        <translation>&lt;br&gt;&lt;br&gt;Aktuell unterstützte Datenquellen:&lt;br&gt;&lt;b&gt;DB&lt;/b&gt;, &lt;b&gt;MVV&lt;/b&gt;, &lt;b&gt;SBB&lt;/b&gt;, &lt;b&gt;ÖBB&lt;/b&gt;, &lt;b&gt;Rejseplanen.dk&lt;/b&gt;, &lt;b&gt;131500.com.au&lt;/b&gt;&lt;br&gt;&lt;br&gt;Diese oder frühere Versionen enthalten code gesponsort von:&lt;br&gt;&lt;i&gt;hcm&lt;/i&gt;, &lt;i&gt;thp&lt;/i&gt;, &lt;i&gt;qwerty12&lt;/i&gt;, &lt;i&gt;qbast&lt;/i&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="350"/>
         <source>About Fahrplan</source>
         <translation>Über Fahrplan</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="362"/>
+        <location filename="mainwindow.cpp" line="377"/>
         <source>&lt;br&gt;Details already loading, please wait.&lt;br&gt;</source>
         <translation>&lt;br&gt;Details werden bereits geladen, bitte warten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="376"/>
+        <location filename="mainwindow.cpp" line="391"/>
         <source>&lt;br&gt;Error opening the details.&lt;br&gt;</source>
         <translation>&lt;br&gt;Beim öffnen der Details ist ein Fehler aufgetreten.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="382"/>
+        <location filename="mainwindow.cpp" line="397"/>
         <source>Details</source>
         <translation>Details</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="391"/>
+        <location filename="mainwindow.cpp" line="406"/>
         <source>Add to calendar</source>
         <translation>In Kalender eintragen</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="473"/>
+        <location filename="mainwindow.cpp" line="488"/>
         <source>&lt;br&gt;&lt;b&gt;Duration: &lt;/b&gt;</source>
         <translation>&lt;br&gt;&lt;b&gt;Dauer: &lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="508"/>
+        <location filename="mainwindow.cpp" line="523"/>
         <source>&lt;br&gt;No results found.&lt;br&gt;</source>
         <translation>&lt;br&gt;Keine Ergebnisse gefunden.&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="527"/>
+        <location filename="mainwindow.cpp" line="542"/>
         <source>Results</source>
         <translation>Ergebnis</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="544"/>
+        <location filename="mainwindow.cpp" line="559"/>
         <source>to</source>
         <translation>nach</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="555"/>
+        <location filename="mainwindow.cpp" line="570"/>
         <source>Earlier</source>
         <translation>Früher</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="561"/>
+        <location filename="mainwindow.cpp" line="576"/>
         <source>Later</source>
         <translation>Später</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="574"/>
+        <location filename="mainwindow.cpp" line="589"/>
         <source> transfer</source>
         <translation> umstieg</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="577"/>
+        <location filename="mainwindow.cpp" line="592"/>
         <source> transfers</source>
         <translation> umstiege</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="596"/>
+        <location filename="mainwindow.cpp" line="611"/>
         <source>&lt;br&gt;OnTime</source>
         <translation>&lt;br&gt;Pünktlich</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="732"/>
+        <location filename="mainwindow.cpp" line="747"/>
         <source>&lt;br&gt;Please select a from and to station and make sure they are not the same.&lt;br&gt;</source>
         <translation>&lt;br&gt;Bitte zwei verschiedene Haltestellen wählen.&lt;br&gt;</translation>
     </message>
@@ -371,26 +374,57 @@
     </message>
     <message>
         <location filename="configdialog.cpp" line="63"/>
-        <source>bahn.de</source>
-        <translation>bahn.de</translation>
+        <source>DB - Germany</source>
+        <translation>DB - Deutschland</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="67"/>
-        <source>mvv-muenchen.de</source>
-        <translation>mvv-muenchen.de</translation>
+        <source>MVV - Germany</source>
+        <translation>MVV - Deutschland</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="71"/>
-        <source>sbb.ch</source>
-        <translation>sbb.ch</translation>
+        <source>SBB Legacy - Swiss</source>
+        <translation>SBB Alt - Schweiz</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="75"/>
-        <source>131500.com.au</source>
-        <translation>131500.com.au</translation>
+        <source>NSW - Australia</source>
+        <translation>NSW - Australien</translation>
     </message>
     <message>
         <location filename="configdialog.cpp" line="79"/>
+        <source>ÖBB - Austria</source>
+        <translation>ÖBB - Österreich</translation>
+    </message>
+    <message>
+        <location filename="configdialog.cpp" line="83"/>
+        <source>SBB - Swiss</source>
+        <translation>SBB - Schweiz</translation>
+    </message>
+    <message>
+        <location filename="configdialog.cpp" line="87"/>
+        <source>Rejseplanen - Denmark</source>
+        <translation>Rejseplanen - Dänemark</translation>
+    </message>
+    <message>
+        <source>bahn.de</source>
+        <translation type="obsolete">bahn.de</translation>
+    </message>
+    <message>
+        <source>mvv-muenchen.de</source>
+        <translation type="obsolete">mvv-muenchen.de</translation>
+    </message>
+    <message>
+        <source>sbb.ch</source>
+        <translation type="obsolete">sbb.ch</translation>
+    </message>
+    <message>
+        <source>131500.com.au</source>
+        <translation type="obsolete">131500.com.au</translation>
+    </message>
+    <message>
+        <location filename="configdialog.cpp" line="91"/>
         <source>Databackend</source>
         <translation>Datenquelle</translation>
     </message>
@@ -424,22 +458,107 @@
     </message>
 </context>
 <context>
-    <name>parserMobileBahnDe</name>
+    <name>parserHafasXml</name>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="163"/>
+        <location filename="parser_hafasxml.cpp" line="159"/>
+        <source>Internal Error occured!</source>
+        <translation>Interner Fehler!</translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="343"/>
         <source>All</source>
         <translation>Alle</translation>
     </message>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="164"/>
+        <location filename="parser_hafasxml.cpp" line="344"/>
         <source>All without ICE</source>
         <translation>Alle ohne ICE</translation>
     </message>
     <message>
-        <location filename="parser_mobilebahnde.cpp" line="165"/>
+        <location filename="parser_hafasxml.cpp" line="345"/>
         <source>Only local transport</source>
         <translation>Nur Nahverkehr</translation>
     </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="346"/>
+        <source>Local transport without S-Bahn</source>
+        <translation>Nur Nahverkehr ohne S-Bahn</translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="582"/>
+        <location filename="parser_hafasxml.cpp" line="588"/>
+        <source>Platform </source>
+        <translation>Gleis</translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="584"/>
+        <location filename="parser_hafasxml.cpp" line="590"/>
+        <source>on</source>
+        <translation>am</translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="636"/>
+        <location filename="parser_hafasxml.cpp" line="649"/>
+        <source>Walk for </source>
+        <translation>Zu Fuss für </translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="636"/>
+        <location filename="parser_hafasxml.cpp" line="639"/>
+        <location filename="parser_hafasxml.cpp" line="642"/>
+        <location filename="parser_hafasxml.cpp" line="645"/>
+        <location filename="parser_hafasxml.cpp" line="649"/>
+        <source> min.</source>
+        <translation>min.</translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="639"/>
+        <source>Use a Bike for </source>
+        <translation>Per Fahrrad für </translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="642"/>
+        <source>Use a car for </source>
+        <translation>Per Auto für </translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="645"/>
+        <source>Take a taxi for </source>
+        <translation>Per Taxi für </translation>
+    </message>
+    <message>
+        <location filename="parser_hafasxml.cpp" line="688"/>
+        <source>d</source>
+        <translation>t</translation>
+    </message>
+</context>
+<context>
+    <name>parserMobileBahnDe</name>
+    <message>
+        <location filename="parser_mobilebahnde.cpp" line="48"/>
+        <source>Warning</source>
+        <translation>Achtung</translation>
+    </message>
+    <message>
+        <location filename="parser_mobilebahnde.cpp" line="173"/>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <location filename="parser_mobilebahnde.cpp" line="174"/>
+        <source>All without ICE</source>
+        <translation>Alle ohne ICE</translation>
+    </message>
+    <message>
+        <location filename="parser_mobilebahnde.cpp" line="175"/>
+        <source>Only local transport</source>
+        <translation>Nur Nahverkehr</translation>
+    </message>
+    <message>
+        <location filename="parser_mobilebahnde.cpp" line="176"/>
+        <source>Local transport without S-Bahn</source>
+        <translation>Nur Nahverker ohne S-Bahn</translation>
+    </message>
 </context>
 <context>
     <name>parserMvvDe</name>
@@ -464,6 +583,50 @@
         <translation>Tram</translation>
     </message>
 </context>
+<context>
+    <name>parserXmlOebbAt</name>
+    <message>
+        <location filename="parser_xmloebbat.cpp" line="37"/>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <location filename="parser_xmloebbat.cpp" line="38"/>
+        <source>All without ICE, TGV</source>
+        <translation>Alle ohne ICE, TGV</translation>
+    </message>
+    <message>
+        <location filename="parser_xmloebbat.cpp" line="39"/>
+        <source>Einfach-Raus-Ticket</source>
+        <translation>Einfach-Raus-Ticket</translation>
+    </message>
+</context>
+<context>
+    <name>parserXmlRejseplanenDk</name>
+    <message>
+        <location filename="parser_xmlrejseplanendk.cpp" line="50"/>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <location filename="parser_xmlrejseplanendk.cpp" line="51"/>
+        <source>All without ICE</source>
+        <translation>Alle ohne ICE</translation>
+    </message>
+</context>
+<context>
+    <name>parserXmlSbbCh</name>
+    <message>
+        <location filename="parser_xmlsbbch.cpp" line="49"/>
+        <source>All</source>
+        <translation>Alle</translation>
+    </message>
+    <message>
+        <location filename="parser_xmlsbbch.cpp" line="50"/>
+        <source>All without ICE</source>
+        <translation>Alle ohne ICE</translation>
+    </message>
+</context>
 <context>
     <name>selectStationDialog</name>
     <message>
@@ -482,7 +645,7 @@
         <translation>Suchen</translation>
     </message>
     <message>
-        <location filename="selectstationdialog.cpp" line="135"/>
+        <location filename="selectstationdialog.cpp" line="147"/>
         <source>Select a station</source>
         <translation>Haltestelle wählen</translation>
     </message>
