@@ -206,19 +206,35 @@ void MainWindow::initBackend(bool resetStations)
     if (backendType == "parserMobileBahnDe")
     {
         backendParser = new parserMobileBahnDe();
-        setWindowTitle("Fahrplan (bahn.de)");
+        setWindowTitle("Fahrplan (DB)");
     } else if (backendType == "parserMvvDe")
     {
         backendParser = new parserMvvDe();
-        setWindowTitle("Fahrplan (mvv-muenchen.de)");
+        setWindowTitle("Fahrplan (MVV)");
     } else if (backendType == "parserSbbCh")
     {
         backendParser = new parserSbbCh();
-        setWindowTitle("Fahrplan (sbb.ch)");
+        setWindowTitle("Fahrplan (SBB-Legacy)");
     } else if (backendType == "parser131500ComAu")
     {
         backendParser = new parser131500ComAu();
-        setWindowTitle("Fahrplan (131500.com.au)");
+        setWindowTitle("Fahrplan (NSW)");
+    } else if (backendType == "parserXmlOebbAt")
+    {
+        backendParser = new parserXmlOebbAt();
+        setWindowTitle("Fahrplan (BB)");
+    } else if (backendType == "parserXmlSbbCh")
+    {
+        backendParser = new parserXmlSbbCh();
+        setWindowTitle("Fahrplan (SBB)");
+    } else if (backendType == "parserXmlRejseplanenDk")
+    {
+        backendParser = new parserXmlRejseplanenDk();
+        setWindowTitle("Fahrplan (Rejseplanen)");
+    } else if (backendType == "parserHafasXml")
+    {
+        backendParser = new parserHafasXml();
+        setWindowTitle("Fahrplan (hafasXml - alpha)");
     } else
     {
        //fallback is bahn.de
@@ -329,7 +345,7 @@ void MainWindow::donateButtonClicked()
 void MainWindow::aboutButtonClicked()
 {
     QString version = APP_VER;
-    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>bahn.de</b>, <b>mvv-muenchen.de</b>, <b>sbb.ch</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
+    QString aboutMsg = tr("by smurfy (maemo@smurfy.de)<br>Version ") + version + tr("<br><br>Current supported databackends:<br><b>DB</b>, <b>MVV</b>, <b>SBB</b>, <b>BB</b>, <b>Rejseplanen.dk</b>, <b>131500.com.au</b><br><br>This or prior versions uses code contribution by:<br><i>hcm</i>, <i>thp</i>, <i>qwerty12</i>, <i>qbast</i>");
     QMessageBox::about(this,
                        tr("About Fahrplan"),
                        tr(aboutMsg.toAscii()));
