@@ -23,9 +23,14 @@
 
 #include <QMainWindow>
 #include <QtGui>
+#ifdef Q_WS_MAEMO_5
 #include <QtMaemo5>
-#include <QMaemo5InformationBox>
-#include <qgtkstyle.h>
+    #include <QMaemo5InformationBox>
+    #include <qgtkstyle.h>
+    #include <qgeopositioninfo.h>
+    #include <qgeopositioninfosource.h>
+    #include "calendardialog.h"
+#endif
 #include <QtCore/QtGlobal>
 #include <QtCore/QtDebug>
 
@@ -33,24 +38,26 @@
 #include <QtCore/QBuffer>
 #include <QtCore/QStringList>
 #include <QCloseEvent>
-#include <qgeopositioninfo.h>
-#include <qgeopositioninfosource.h>
-
 #include "parser_abstract.h"
 #include "parser_mobilebahnde.h"
 #include "parser_mvvde.h"
 #include "parser_sbbch.h"
 #include "parser_131500comau.h"
+#include "parser_hafasxml.h"
+#include "parser_xmloebbat.h"
+#include "parser_xmlrejseplanendk.h"
+#include "parser_xmlsbbch.h"
 #include "selectstationdialog.h"
 #include "configdialog.h"
-#include "calendardialog.h"
 #include "qvaluebutton.h"
 
-#define APP_VER "0.0.24"
+#define APP_VER "0.0.25"
 #define APP_FIRSTLAUNCH false
 
-//Use the QtMobility namespace
-QTM_USE_NAMESPACE
+#ifdef Q_WS_MAEMO_5
+    //Use the QtMobility namespace
+    QTM_USE_NAMESPACE
+#endif
 
 class ResultItemUserData : public QObjectUserData
 {
