@@ -173,6 +173,7 @@ QStringList parserMobileBahnDe::getTrainRestrictions()
     result.append(tr("All"));
     result.append(tr("All without ICE"));
     result.append(tr("Only local transport"));
+    result.append(tr("Local transport without S-Bahn"));
     return result;
 }
 
@@ -422,6 +423,8 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
         trainrestr = "2:0111111111000000"; //All without ICE
     } else if (trainrestrictions == 2) {
         trainrestr = "4:00011111110000000"; //Only local transport
+    } else if (trainrestrictions == 3) {
+        trainrestr = "4:0001011111000000"; //Only local transport without S-Bahn
     }
 
     QUrl url("http://mobile.bahn.de/bin/mobil/query.exe/eox?rt=1&use_realtime_filter=1&searchMode=NORMAL");
