@@ -397,9 +397,15 @@ ResultInfo parserSbbCh::parseJourneyData(QByteArray data)
     element.replace(" value=\"yes\">", " value=\"yes\" />");
     element.replace(" nowrap ", " nowrap=\"true\" ");
     element.replace(" nowrap>", " nowrap=\"true\">");
-    QRegExp ahrefReg = QRegExp("href=\"(.*)\"");
-    ahrefReg.setMinimal(true);
-    element.replace(ahrefReg, "");
+    QRegExp advRegex = QRegExp("href=\"(.*)\"");
+    advRegex.setMinimal(true);
+    element.replace(advRegex, "");
+    advRegex = QRegExp("<script(.*)</script>");
+    advRegex.setMinimal(true);
+    element.replace(advRegex, "");
+    advRegex = QRegExp("<table class=\"hafas-tp-result-overview\">(.*)</table>");
+    advRegex.setMinimal(true);
+    element.replace(advRegex, "");
     element.replace("&nbsp;", " ");
 
     //qDebug() <<element;
