@@ -68,8 +68,6 @@ selectStationDialog::selectStationDialog(QValueButton *sender, QGeoPositionInfo
         gpsButton->setEnabled(false);
     }
 
-    gpsButton->setMinimumWidth(210);
-    searchButton->setMinimumWidth(210);
     searchboxCombo->setFixedHeight(72);
     searchboxText->setFixedHeight(72);
 
@@ -77,6 +75,14 @@ selectStationDialog::selectStationDialog(QValueButton *sender, QGeoPositionInfo
 
     setLayout(layout);
     orientationChanged();
+
+    if (settings->value("storelastsearch", true).toBool() ==  true)
+    {
+        searchboxCombo->setFocus();
+    } else
+    {
+        searchboxText->setFocus();
+    }
 }
 
 void selectStationDialog::orientationChanged()
@@ -85,6 +91,9 @@ void selectStationDialog::orientationChanged()
     QGridLayout *layout = (QGridLayout*)this->layout();
     if (screenGeometry.width() > screenGeometry.height())
     {
+        gpsButton->setFixedWidth(210);
+        searchButton->setFixedWidth(210);
+
         layout->addWidget(gpsButton, 0, 1);
         layout->addWidget(searchButton, 1, 1);
         if (settings->value("storelastsearch", true).toBool() ==  true)
@@ -95,6 +104,9 @@ void selectStationDialog::orientationChanged()
             layout->addWidget(searchboxText, 0, 0, 0, 1);
         }
     } else {
+        gpsButton->setMinimumWidth(210);
+        searchButton->setMinimumWidth(210);
+
         layout->addWidget(gpsButton, 1, 0);
         layout->addWidget(searchButton, 1, 1);
         if (settings->value("storelastsearch", true).toBool() ==  true)
